pub enum LevinMessage<T: LevinBody> {
Body(T),
Bucket(Bucket<T::Command>),
Dummy(usize),
}Expand description
A levin message that can be sent to a peer.
Variants
Body(T)
A message body.
A levin header will be added to this message before it is sent to the peer.
Bucket(Bucket<T::Command>)
A full levin bucket.
This bucket will be sent to the peer directly with no extra information.
This should only be used to send fragmented messages: make_fragmented_messages
Dummy(usize)
A dummy message.
A dummy message which the peer will ignore. The dummy message will be the exact size
(in bytes) of the given usize on the wire.